==> jc-1.4.0.tar.gz: soot/coffi/attribute__5finfo.h <==
// class soot.coffi.attribute_info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_attribute__5finfo_H_
#define _JC_soot_coffi_attribute__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_attribute__5finfo$sub_refs	_jc_soot_coffi_attribute__5finfo$sub_refs;
typedef struct _jc_soot_coffi_attribute__5finfo$sub_nonrefs	_jc_soot_coffi_attribute__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_attribute__5finfo$refs	_jc_soot_coffi_attribute__5finfo$refs;
typedef struct _jc_soot_coffi_attribute__5finfo$nonrefs	_jc_soot_coffi_attribute__5finfo$nonrefs;
typedef struct _jc_soot_coffi_attribute__5finfo$object	_jc_soot_coffi_attribute__5finfo$object;

typedef struct _jc_soot_coffi_attribute__5finfo$fields_struct	_jc_soot_coffi_attribute__5finfo$fields_struct;
typedef const struct _jc_soot_coffi_attribute__5finfo$vmethods	_jc_soot_coffi_attribute__5finfo$vmethods;
typedef const struct _jc_soot_coffi_attribute__5finfo$vtable	_jc_soot_coffi_attribute__5finfo$vtable;
typedef const struct _jc_soot_coffi_attribute__5finfo$vtype	_jc_soot_coffi_attribute__5finfo$vtype;

// Class fields structure
struct _jc_soot_coffi_attribute__5finfo$fields_struct {
	struct _jc_java_lang_String$object	*Code;
	struct _jc_java_lang_String$object	*ConstantValue;
	struct _jc_java_lang_String$object	*Exceptions;
	struct _jc_java_lang_String$object	*InnerClasses;
	struct _jc_java_lang_String$object	*LineNumberTable;
	struct _jc_java_lang_String$object	*LocalVariableTable;
	struct _jc_java_lang_String$object	*SourceFile;
};
extern _jc_soot_coffi_attribute__5finfo$fields_struct _jc_soot_coffi_attribute__5finfo$class_fields;

// Constructors
extern void _jc_soot_coffi_attribute__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_attribute__5finfo$object *);

// Virtual methods structure
struct _jc_soot_coffi_attribute__5finfo$vmethods {
};

// Vtable
struct _jc_soot_coffi_attribute__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_attribute__5finfo$vmethods	soot_coffi_attribute__5finfo;
};

// Vtype
struct _jc_soot_coffi_attribute__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_attribute__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_attribute__5finfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_attribute__5finfo$refs {
    _jc_soot_coffi_attribute__5finfo$sub_refs	soot_coffi_attribute__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_attribute__5finfo$sub_nonrefs {
	jint	attribute__5fname;
	jlong	attribute__5flength;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_attribute__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_attribute__5finfo$sub_nonrefs	soot_coffi_attribute__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_attribute__5finfo$object {
	_jc_soot_coffi_attribute__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_attribute__5finfo$vtype	*vtype;
	_jc_soot_coffi_attribute__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_attribute__5finfo$vtype _jc_soot_coffi_attribute__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_attribute__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_attribute__5finfo$class_object;

#endif	/* _JC_soot_coffi_attribute__5finfo_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/attribute__5finfo.h <==
// class soot.coffi.attribute_info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_attribute__5finfo_H_
#define _JC_soot_coffi_attribute__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_attribute__5finfo$sub_refs	_jc_soot_coffi_attribute__5finfo$sub_refs;
typedef struct _jc_soot_coffi_attribute__5finfo$sub_nonrefs	_jc_soot_coffi_attribute__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_attribute__5finfo$refs	_jc_soot_coffi_attribute__5finfo$refs;
typedef struct _jc_soot_coffi_attribute__5finfo$nonrefs	_jc_soot_coffi_attribute__5finfo$nonrefs;
typedef struct _jc_soot_coffi_attribute__5finfo$object	_jc_soot_coffi_attribute__5finfo$object;

typedef struct _jc_soot_coffi_attribute__5finfo$fields_struct	_jc_soot_coffi_attribute__5finfo$fields_struct;
typedef const struct _jc_soot_coffi_attribute__5finfo$vmethods	_jc_soot_coffi_attribute__5finfo$vmethods;
typedef const struct _jc_soot_coffi_attribute__5finfo$vtable	_jc_soot_coffi_attribute__5finfo$vtable;
typedef const struct _jc_soot_coffi_attribute__5finfo$vtype	_jc_soot_coffi_attribute__5finfo$vtype;

// Class fields structure
struct _jc_soot_coffi_attribute__5finfo$fields_struct {
	struct _jc_java_lang_String$object	*Code;
	struct _jc_java_lang_String$object	*ConstantValue;
	struct _jc_java_lang_String$object	*Exceptions;
	struct _jc_java_lang_String$object	*InnerClasses;
	struct _jc_java_lang_String$object	*LineNumberTable;
	struct _jc_java_lang_String$object	*LocalVariableTable;
	struct _jc_java_lang_String$object	*SourceFile;
};
extern _jc_soot_coffi_attribute__5finfo$fields_struct _jc_soot_coffi_attribute__5finfo$class_fields;

// Constructors
extern void _jc_soot_coffi_attribute__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_attribute__5finfo$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_attribute__5finfo$vmethods {
};

// Vtable
struct _jc_soot_coffi_attribute__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_attribute__5finfo$vmethods	soot_coffi_attribute__5finfo;
};

// Vtype
struct _jc_soot_coffi_attribute__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_attribute__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_attribute__5finfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_attribute__5finfo$refs {
    _jc_soot_coffi_attribute__5finfo$sub_refs	soot_coffi_attribute__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_attribute__5finfo$sub_nonrefs {
	jint	attribute__5fname;
	jlong	attribute__5flength;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_attribute__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_attribute__5finfo$sub_nonrefs	soot_coffi_attribute__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_attribute__5finfo$object {
	_jc_soot_coffi_attribute__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_attribute__5finfo$vtype	*vtype;
	_jc_soot_coffi_attribute__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_attribute__5finfo$vtype _jc_soot_coffi_attribute__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_attribute__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_attribute__5finfo$class_object;

#endif	/* _JC_soot_coffi_attribute__5finfo_H_ */
